@@ -2,6 +2,7 @@
 
 #![cfg_attr(feature = "dox", feature(doc_cfg))]
 #![allow(clippy::upper_case_acronyms)]
+#![doc = include_str!("../README.md")]
 
 pub use ffi;
 pub use gdk;
@@ -14,4 +15,6 @@ mod rt;
 #[allow(unused_imports)]
 mod auto;
 
+pub mod builders;
+
 pub use crate::auto::*;
